@@ -87,7 +87,7 @@ ProcXIQueryDevice(ClientPtr client)
     }
     else
     {
-        skip = xcalloc(sizeof(Bool), inputInfo.numDevices);
+        skip = calloc(sizeof(Bool), inputInfo.numDevices);
         if (!skip)
             return BadAlloc;
 
@@ -106,7 +106,7 @@ ProcXIQueryDevice(ClientPtr client)
         }
     }
 
-    info = xcalloc(1, len);
+    info = calloc(1, len);
     if (!info)
         return BadAlloc;
 
@@ -155,8 +155,8 @@ ProcXIQueryDevice(ClientPtr client)
 
     WriteReplyToClient(client, sizeof(xXIQueryDeviceReply), &rep);
     WriteToClient(client, rep.length * 4, ptr);
-    xfree(ptr);
-    xfree(skip);
+    free(ptr);
+    free(skip);
     return rc;
 }
 
@@ -247,6 +247,9 @@ ListButtonInfo(DeviceIntPtr dev, xXIButtonInfo* info, Bool reportState)
     int mask_len;
     int i;
 
+    if (!dev || !dev->button)
+	return 0;
+
     mask_len = bytes_to_int32(bits_to_bytes(dev->button->numButtons));
 
     info->type = ButtonClass;
@@ -259,7 +262,7 @@ ListButtonInfo(DeviceIntPtr dev, xXIButtonInfo* info, Bool reportState)
     memset(bits, 0, mask_len * 4);
 
     if (reportState)
-	for (i = 0; dev && dev->button && i < dev->button->numButtons; i++)
+	for (i = 0; i < dev->button->numButtons; i++)
 	    if (BitIsOn(dev->button->down, i))
 		SetBit(bits, i);
 
